#!/usr/bin/perl -w

# Before `make install' is performed this script should be runnable with
# `make test'. 

#########################

# change 'tests => 1' to 'tests => last_test_to_print';
use strict;
use warnings;

use MinMax;


BEGIN { 
	use GetDictionaryWords;
	#print `pwd`;
	use Test::More;
	#plan tests => (3 + scalar(@$words));
	#my $max_words = 5_000;
	my $max_words = min(1_000_000, ($ENV{MAX_INDEX_FILES} || 0));
	plan tests => (3 * (min($max_words, 234940) + min($max_words,45427)  + 6) );	
	use Swishetest;
	use File::Path qw(mkpath);
	mkpath( ["blib/index"], 0, 0755);
	my $base = "C030";
	for my $dict (qw( data/C020-words-txt/words-linux-fc1.txt data/C020-words-txt/words-osx-10_3.txt)) {
		for my $filetype (qw( html xml txt )) {
			( my $dictname = $dict ) =~ s/^.*-([^.]+)\.txt$/$1/;

			my $index = "blib/index/${base}_${dictname}_${filetype}.index";
			my ($words, $word_count) = get_dictionary_words( $dict, 0, $max_words);
				# this filename should come from somewhere factored
			die "Couldn't get words from $dict" unless @$words;
			my $cmd = "./make_collection --dict=$dict --norand --noenglishify " .
						"--filetype=$filetype --min_words=1 --max_words=1 --num_files=" . scalar(@$words);
			print STDERR "Using $cmd\n" if $ENV{TEST_VERBOSE};

			my (%out) = build_index_from_external_program( $cmd, $index);

			# first three tests: did the indexing seem to work?
			cmp_ok( scalar(%out),     '>',          0, 		"Indexing output" ); 
			cmp_ok( $out{files},      '==', scalar(@$words), 'files indexed' );
			cmp_ok( $out{properties}, '==',         4, 		'num properties' );

			open_index($index);
			for my $word (@$words) {	# then, one test for each word in the lest
				my @rows = do_search($index, $word);
				my ($num_expected_rows) = (		# look up the count unless it's AND, OR, or NOT
					($word =~ /^\s*(and|or|not)\s*$/i) ? 0 : ($word_count->{lc($word)} || 1));
				cmp_ok(scalar(@rows), "==", $num_expected_rows, "search '$word' ($filetype from $dictname)");
			}
			close_index($index);
			$words = undef;
			$word_count = undef;
		}
	}
};

__END__

BEGIN { 
	use File::Path qw(mkpath);
	mkpath( ["blib/index"], 0, 0755);
	my $base = "C030";
	my (%out) = build_index( 
		"data/C030-medsm-xml", "blib/index/$base.index");

	cmp_ok( scalar(%out),     '>',          2, "Indexing output" ); 
	cmp_ok( $out{unique},     '==',    117468, 'unique words indexed' );
	cmp_ok( $out{properties}, '==',         4, 'num properties' );
	cmp_ok( $out{files},      '==',      1000, 'files indexed' );
	cmp_ok( $out{bytes},      '==',  16626260, 'bytes indexed' );
	cmp_ok( $out{words},      '==',   1513714, 'total words indexed' );

	
	my @rows = do_search( 
		"blib/index/$base.index", "swishe OR test");
	cmp_ok(scalar(@rows), '==', 14, "num results from 'swishe OR test'") 
};

